@@ -13,6 +13,7 @@
 #' sample(lines, size = 2)
 #' @export
 vroom_lines <- function(file, n_max = Inf, skip = 0,
+  na = character(), skip_empty_rows = FALSE,
   locale = default_locale(), altrep = TRUE,
   altrep_opts = deprecated(), num_threads = vroom_threads(),
   progress = vroom_progress()) {
@@ -24,6 +25,11 @@ vroom_lines <- function(file, n_max = Inf, skip = 0,
 
   file <- standardise_path(file)
 
+  if (!is_ascii_compatible(locale$encoding)) {
+    file <- reencode_path(file, locale$encoding)
+    locale$encoding <- "UTF-8"
+  }
+
   if (n_max < 0 || is.infinite(n_max)) {
     n_max <- -1
   }
@@ -40,9 +46,10 @@ vroom_lines <- function(file, n_max = Inf, skip = 0,
   # in character vectors.
   out <- vroom_(file, delim = "\1", col_names = "V1", col_types = cols(col_character()),
     id = NULL, skip = skip, col_select = col_select, name_repair = "minimal",
-    na = character(), quote = "", trim_ws = FALSE, escape_double = FALSE,
-    escape_backslash = FALSE, comment = "", locale = locale, guess_max = 0,
-    n_max = n_max, altrep = vroom_altrep(altrep), num_threads = num_threads,
+    na = na, quote = "", trim_ws = FALSE, escape_double = FALSE,
+    escape_backslash = FALSE, comment = "", skip_empty_rows = skip_empty_rows,
+    locale = locale, guess_max = 0, n_max = n_max,
+    altrep = vroom_altrep(altrep), num_threads = num_threads,
     progress = progress
   )
   if (length(out) == 0) {
