@@ -18,7 +18,7 @@ test_that("datetime parsing works", {
 r_parse <- function(x, fmt) as.POSIXct(strptime(x, fmt, tz = "UTC"))
 
 test_that("%d, %m and %y", {
-  target <- readr:::utctime(2010, 2, 3, 0, 0, 0, 0)
+  target <- utctime(2010, 2, 3, 0, 0, 0, 0)
 
   test_parse_datetime("10-02-03", "%y-%m-%d", expected = target)
   test_parse_datetime("10-03-02", "%y-%d-%m", expected = target)
@@ -27,7 +27,7 @@ test_that("%d, %m and %y", {
 })
 
 test_that("Compound formats work", {
-  target <- readr:::utctime(2010, 2, 3, 0, 0, 0, 0)
+  target <- utctime(2010, 2, 3, 0, 0, 0, 0)
 
   test_parse_datetime("02/03/10", "%D", expected = target)
   test_parse_datetime("2010-02-03", "%F", expected = target)
@@ -40,38 +40,38 @@ test_that("%y matches R behaviour", {
 })
 
 test_that("%e allows leading space", {
-  test_parse_datetime("201010 1", "%Y%m%e", expected = readr:::utctime(2010, 10, 1, 0, 0, 0, 0))
+  test_parse_datetime("201010 1", "%Y%m%e", expected = utctime(2010, 10, 1, 0, 0, 0, 0))
 })
 
 test_that("%OS captures partial seconds", {
-  test_parse_datetime("2001-01-01 00:00:01.125", "%Y-%m-%d %H:%M:%OS", expected = readr:::utctime(2001, 1, 1, 0, 0, 1, .125))
-  test_parse_datetime("2001-01-01 00:00:01.133", "%Y-%m-%d %H:%M:%OS", expected = readr:::utctime(2001, 1, 1, 0, 0, 1, .133))
+  test_parse_datetime("2001-01-01 00:00:01.125", "%Y-%m-%d %H:%M:%OS", expected = utctime(2001, 1, 1, 0, 0, 1, .125))
+  test_parse_datetime("2001-01-01 00:00:01.133", "%Y-%m-%d %H:%M:%OS", expected = utctime(2001, 1, 1, 0, 0, 1, .133))
 })
 
 test_that("%Y requires 4 digits", {
-  expect_warning(test_parse_date("03-01-01", "%Y-%m-%d", expected = as.Date(NA)))
-  expect_warning(test_parse_date("003-01-01", "%Y-%m-%d", expected = as.Date(NA)))
+  test_parse_date("03-01-01", "%Y-%m-%d", expected = as.Date(NA))
+  test_parse_date("003-01-01", "%Y-%m-%d", expected = as.Date(NA))
   test_parse_date("0003-01-01", "%Y-%m-%d", expected = as.Date("0003-01-01"))
-  expect_warning(test_parse_date("00003-01-01", "%Y-%m-%d", expected = as.Date(NA)))
+  test_parse_date("00003-01-01", "%Y-%m-%d", expected = as.Date(NA))
 })
 
 test_that("invalid dates return NA", {
-  expect_warning(test_parse_datetime("2010-02-30", "%Y-%m-%d", expected = .POSIXct(NA_real_, tz = "UTC")))
+  test_parse_datetime("2010-02-30", "%Y-%m-%d", expected = .POSIXct(NA_real_, tz = "UTC"))
 })
 
 test_that("failed parsing returns NA", {
-  expect_warning(test_parse_datetime(c("2010-02-ab", "2010-02", "2010/02/01"), "%Y-%m-%d",
-    expected = .POSIXct(rep(NA_real_, 3), tz = "UTC")))
+  test_parse_datetime(c("2010-02-ab", "2010-02", "2010/02/01"), "%Y-%m-%d",
+    expected = .POSIXct(rep(NA_real_, 3), tz = "UTC"))
 })
 
 test_that("invalid specs returns NA", {
-  expect_warning(test_parse_datetime("2010-02-20", "%Y-%m-%m", expected = .POSIXct(NA_real_, tz = "UTC")))
+  test_parse_datetime("2010-02-20", "%Y-%m-%m", expected = .POSIXct(NA_real_, tz = "UTC"))
 })
 
 test_that("ISO8601 partial dates are not parsed", {
-  expect_warning(test_parse_datetime("20", "", expected = .POSIXct(NA_real_, tz = "UTC")))
-  expect_warning(test_parse_datetime("2001", "", expected = .POSIXct(NA_real_, tz = "UTC")))
-  expect_warning(test_parse_datetime("2001-01", "", expected = .POSIXct(NA_real_, tz = "UTC")))
+  test_parse_datetime("20", "", expected = .POSIXct(NA_real_, tz = "UTC"))
+  test_parse_datetime("2001", "", expected = .POSIXct(NA_real_, tz = "UTC"))
+  test_parse_datetime("2001-01", "", expected = .POSIXct(NA_real_, tz = "UTC"))
 })
 
 test_that("Year only gets parsed", {
@@ -97,8 +97,8 @@ test_that("%p detects AM/PM", {
   test_parse_datetime("12/31/1991 01:01 AM", "%m/%d/%Y %I:%M %p",
     expected = .POSIXct(694141260, "UTC"))
 
-  expect_warning(test_parse_datetime(c("12/31/1991 00:01 PM", "12/31/1991 13:01 PM"),
-      "%m/%d/%Y %I:%M %p", expected = .POSIXct(rep(NA_real_, 2), tz = "UTC")))
+  test_parse_datetime(c("12/31/1991 00:01 PM", "12/31/1991 13:01 PM"),
+      "%m/%d/%Y %I:%M %p", expected = .POSIXct(rep(NA_real_, 2), tz = "UTC"))
 })
 
 test_that("%b and %B are case insensitive", {
@@ -112,7 +112,7 @@ test_that("%. requires a value", {
   ref <- as.Date("2001-01-01")
 
   test_parse_date("2001?01?01", "%Y%.%m%.%d", expected = ref)
-  expect_warning(test_parse_date("20010101", "%Y%.%m%.%d", expected = as.Date(NA)))
+  test_parse_date("20010101", "%Y%.%m%.%d", expected = as.Date(NA))
 })
 
 test_that("%Z detects named time zones", {
@@ -123,6 +123,12 @@ test_that("%Z detects named time zones", {
   test_parse_datetime("2010-10-01 01:00 America/Chicago", "%Y-%m-%d %H:%M %Z", locale = ct, expected = ref)
 })
 
+test_that("%Z detects named time zones", {
+  ref <- .POSIXct(1285912800, "UTC")
+
+  test_parse_datetime("1285912800", "%s", expected = ref)
+})
+
 test_that("parse_date returns a double like as.Date()", {
   ref <- as.Date("2001-01-01")
 
@@ -132,12 +138,12 @@ test_that("parse_date returns a double like as.Date()", {
 
 test_that("parses NA/empty correctly", {
   expect_equal(
-    vroom("x\n\n", delim = ",", col_types = list(x = "T")),
+    vroom(I("x\n\n"), delim = ",", col_types = list(x = "T"), skip_empty_rows = FALSE),
     tibble::tibble(x = .POSIXct(NA_real_, tz = "UTC"))
   )
 
   expect_equal(
-    vroom("x\n\n", delim = ",", col_types = list(x = "D")),
+    vroom(I("x\n\n"), delim = ",", col_types = list(x = "D"), skip_empty_rows = FALSE),
     tibble::tibble(x = as.Date(NA))
   )
 
@@ -174,18 +180,17 @@ test_that("locale affects am/pm", {
   test_parse_time("\UC624\UD6C4 01\UC2DC 30\UBD84", "%p %H\UC2DC %M\UBD84", expected = expected, locale = locale("ko"))
 })
 
-#test_that("locale affects both guessing and parsing", {
-  ##TODO: not working
-  #out <- vroom("01/02/2013\n", col_names = FALSE, locale = locale(date_format = "%m/%d/%Y"))
-  #expect_equal(out, as.Date("2013-01-02"))
-#})
+test_that("locale affects both guessing and parsing", {
+  out <- vroom(I("01/02/2013\n"), delim = ",", col_names = FALSE, col_types = list(), locale = locale(date_format = "%m/%d/%Y"))
+  expect_equal(out[[1]][[1]], as.Date("2013-01-02"))
+})
 
 ## Time zones ------------------------------------------------------------------
 
 test_that("same times with different offsets parsed as same time", {
   # From http://en.wikipedia.org/wiki/ISO_8601#Time_offsets_from_UTC
   same_time <- paste("2010-02-03", c("18:30Z", "22:30+04", "1130-0700", "15:00-03:30"))
-  test_parse_datetime(same_time, format = "", expected = rep(readr:::utctime(2010, 2, 3, 18, 30, 0, 0), 4))
+  test_parse_datetime(same_time, format = "", expected = rep(utctime(2010, 2, 3, 18, 30, 0, 0), 4))
 })
 
 test_that("offsets can cross date boundaries", {
@@ -210,23 +215,52 @@ test_that("unambiguous times with and without daylight savings", {
   test_parse_datetime(c("2015-04-04 12:00:00", "2015-04-06 12:00:00"), locale = ja, expected = expected_ja)
 })
 
+test_that("ambiguous times always choose the earliest time", {
+  ny <- locale(tz = "America/New_York")
+
+  format <- "%Y-%m-%d %H:%M:%S%z"
+  expected <- as.POSIXct("1970-10-25 01:30:00-0400", tz = "America/New_York", format = format)
+
+  test_parse_datetime("1970-10-25 01:30:00", locale = ny, expected = expected)
+})
+
+test_that("nonexistent times return NA", {
+  ny <- locale(tz = "America/New_York")
+  expected <- .POSIXct(NA_real_, tz = "America/New_York")
+
+  test_parse_datetime("1970-04-26 02:30:00", locale = ny, expected = expected)
+})
+
+test_that("can use `tz = ''` for system time zone", {
+  withr::local_timezone("Europe/London")
+
+  system <- locale(tz = "")
+  expected <- as.POSIXct("1970-01-01 00:00:00", tz = "Europe/London")
+
+  test_parse_datetime("1970-01-01 00:00:00", locale = system, expected = expected)
+})
+
+test_that("can catch faulty system time zones", {
+  withr::local_timezone("foo")
+  expect_error(locale(tz = ""), "Unknown TZ foo")
+})
 
 ## Guessing ---------------------------------------------------------------------
 
 test_that("DDDD-DD not parsed as date (i.e. doesn't trigger partial date match)", {
-  expect_type(vroom("1989-90\n1990-91\n", delim = "\n", col_types = list())[[1]], "character")
+  expect_type(vroom(I("1989-90\n1990-91\n"), delim = "\n", col_types = list())[[1]], "character")
 })
 
 test_that("leading zeros don't get parsed as date without explicit separator", {
-  expect_type(vroom("00010203\n", col_names = FALSE, delim = "\n", col_types = list())[[1]], "double")
-  expect_s3_class(vroom("0001-02-03\n", col_names = FALSE, delim = "\n", col_types = list())[[1]], "Date")
+  expect_type(vroom(I("00010203\n"), col_names = FALSE, delim = "\n", col_types = list())[[1]], "double")
+  expect_s3_class(vroom(I("0001-02-03\n"), col_names = FALSE, delim = "\n", col_types = list())[[1]], "Date")
 })
 
 test_that("must have either two - or none", {
-  expect_s3_class(vroom("2000-10-10\n", col_names = FALSE, delim = "\n", col_types = list())[[1]], "Date")
-  expect_type(vroom("2000-1010\n", col_names = FALSE, delim = "\n", col_types = list())[[1]], "character")
-  expect_type(vroom("200010-10\n", col_names = FALSE, delim = "\n", col_types = list())[[1]], "character")
-  expect_type(vroom("20001010\n", col_names = FALSE, delim = "\n", col_types = list())[[1]], "double")
+  expect_s3_class(vroom(I("2000-10-10\n"), col_names = FALSE, delim = "\n", col_types = list())[[1]], "Date")
+  expect_type(vroom(I("2000-1010\n"), col_names = FALSE, delim = "\n", col_types = list())[[1]], "character")
+  expect_type(vroom(I("200010-10\n"), col_names = FALSE, delim = "\n", col_types = list())[[1]], "character")
+  expect_type(vroom(I("20001010\n"), col_names = FALSE, delim = "\n", col_types = list())[[1]], "double")
 })
 
 test_that("times are guessed even without AM / PM", {
@@ -236,7 +270,7 @@ test_that("times are guessed even without AM / PM", {
 })
 
 test_that("subsetting works with both double and integer indexes", {
-  x <- vroom("X1\n2020-01-01 01:01:01", delim = ",", col_type = "T")
+  x <- vroom(I("X1\n2020-01-01 01:01:01"), delim = ",", col_type = "T")
   dt <- as.POSIXct("2020-01-01 01:01:01", tz = "UTC")
   na_dt <- .POSIXct(NA_real_, tz = "UTC")
   expect_equal(x$X1[1L], dt)
@@ -246,17 +280,17 @@ test_that("subsetting works with both double and integer indexes", {
 })
 
 test_that("guessing datetime uses the same logic as parsing", {
-  expect_type(vroom("date\n2015-06-14T09Z\n2015-06-14T09Z", delim=",")[[1]], "character")
+  expect_type(vroom(I("date\n2015-06-14T09Z\n2015-06-14T09Z"), delim=",", col_types = list())[[1]], "character")
 })
 
 test_that("malformed date / datetime formats cause R errors", {
   expect_error(
-    vroom("x\n6/28/2016", delim = ",", col_types = list(x = col_date("%m/%/%Y")), altrep = FALSE),
+    vroom(I("x\n6/28/2016"), delim = ",", col_types = list(x = col_date("%m/%/%Y")), altrep = FALSE),
     "Unsupported format"
   )
 
   expect_error(
-    vroom("x\n6/28/2016", delim = ",", col_types = list(x = col_datetime("%m/%/%Y")), altrep = FALSE),
+    vroom(I("x\n6/28/2016"), delim = ",", col_types = list(x = col_datetime("%m/%/%Y")), altrep = FALSE),
     "Unsupported format"
   )
 })
